@@ -250,12 +250,15 @@ SEXP R_multi_new(void){
   return ptr;
 }
 
-SEXP R_multi_setopt(SEXP pool_ptr, SEXP total_con, SEXP host_con, SEXP multiplex){
+SEXP R_multi_setopt(SEXP pool_ptr, SEXP total_con, SEXP host_con, SEXP max_streams, SEXP multiplex){
     CURLM *multi = get_multiref(pool_ptr)->m;
     massert(curl_multi_setopt(multi, CURLMOPT_MAX_TOTAL_CONNECTIONS, (long) Rf_asInteger(total_con)));
     massert(curl_multi_setopt(multi, CURLMOPT_MAX_HOST_CONNECTIONS, (long) Rf_asInteger(host_con)));
     massert(curl_multi_setopt(multi, CURLMOPT_PIPELINING,
                               Rf_asLogical(multiplex) ? CURLPIPE_MULTIPLEX : CURLPIPE_NOTHING));
+#ifdef HAS_MAX_STREAMS
+    massert(curl_multi_setopt(multi, CURLMOPT_MAX_CONCURRENT_STREAMS, (long) Rf_asInteger(max_streams)));
+#endif
   return pool_ptr;
 }
 
